@@ -197,7 +197,7 @@ def _ttest_matrix(
 def _median_bg_subtraction(
     samples: pd.DataFrame,
     control: str,
-    cnr_thresh: Optional[float] = 1.0,
+    cnr_thresh: Optional[float] = 0.3,
     cnr_max: float = 10.0,
 ) -> Tuple[sp.csr_matrix, sp.csr_matrix]:
     """
@@ -220,13 +220,13 @@ def _median_bg_subtraction(
     cnr.data = np.zeros(sse[0].data.shape)
     diff = sp.csr_matrix(sse[0].shape)
     for c in conditions:
-        if cnr_thresh is not None:
-            cnr.data += backgrounds[c].data / np.sqrt(sse[c].data)
         if c != control:
             # Break ties to preserve sparsity (do not introduce 0s)
             ties = backgrounds[c].data == backgrounds[control].data
             backgrounds[c].data[ties] += 1e-08
-            diff += backgrounds[c] - backgrounds[control]
+            curr_diff = backgrounds[c] - backgrounds[control]
+            diff += curr_diff
+            cnr.data += np.abs(curr_diff.data) / np.sqrt(sse[c].data)
     cnr.data /= len(conditions)
     # Erase spurious or extreme values
     cnr.data[cnr.data < 0.0] = 0.0
@@ -247,7 +247,7 @@ def detection_matrix(
     max_dist: Optional[int] = None,
     pearson_thresh: Optional[float] = None,
     density_thresh: Optional[float] = None,
-    cnr_thresh: Optional[float] = 1.0,
+    cnr_thresh: Optional[float] = 0.3,
     n_cpus: int = 4,
 ) -> Tuple[Optional[sp.csr_matrix], Optional[sp.csr_matrix]]:
     """
